# limix-lmm

[![Travis](https://img.shields.io/travis/com/limix/limix-lmm.svg?style=flat-square&label=linux%20%2F%20macos%20build)](https://travis-ci.com/limix/limix-lmm) [![Documentation](https://img.shields.io/readthedocs/limix-lmm.svg?style=flat-square&version=stable)](https://limix-lmm.readthedocs.io/)

This a standalone module that implements the basic functionalities of LMM-based models for genome-wide association studies.
However, we recommend using this module using [LIMIX2](https://limix.readthedocs.io/en/2.0.0/index.html).

## Install

From terminal, it can be installed using [pip](https://pypi.python.org/pypi/pip):

```bash
pip install limix-lmm
```

## Documentation

The public interface and a quick start in python are available at
[http://limix-lmm.readthedocs.io/](http://struct-lmm.readthedocs.io/).

## Problems

If you encounter any problem, please, consider submitting a [new issue](https://github.com/limix/limix-lmm/issues/new).

## Authors

- **Francesco Paolo Casale** - [https://github.com/fpcasale](https://github.com/fpcasale)
- **Danilo Horta** - [https://github.com/horta](https://github.com/horta)
- **Rachel Moore** - [https://github.com/rm18](https://github.com/rm18)
- **Oliver Stegle** - [https://github.com/ostegle](https://github.com/ostegle)

## License

This project is licensed under the Apache License (Version 2.0, January 2004) -
see the [LICENSE](LICENSE) file for details
